Pērciet BMW 530 2019 2.0 RWD 135 kW G30 , Iperformance 2019 ar patiesu nobraukumu 47522 km Rīgā oficiālā dīlera salonā
Description: Iegādājaties mazlietotu BMW 530 ar nobraukumu 47522 km. Mazlietots BMW 530 2019 2.0 RWD 135 kW G30 , Iperformance Automātiskā par 46800 EUR, mazlietotu automobiļu tirdzniecības vietā Inchcape Certified Rīgā.

16

# BMW 530 2019 2.0 RWD 135 kW G30 , Iperformance, 47522 km

46 800 € (Ieskaitot PVN 21%)
€ 672,75 / mēn.*
Salons:
Inchcape Motors Dārzciema
Dārzciema iela 64A
Tālrunis:
+371 (67) 82-8600
Uzzināt vairāk ONLINE konsultācija Saņemt AutoDNA i Sazināties WhatsApp
Izlaiduma gads
2019-07-26
Dzinējs
Plug-in Hibrīds
Nobraukums
47 522
Pārnesumkārba
Automātiskā
Piedziņas veids
RWD
Virsbūves tips
Sedans
Tehniskie dati
Aprīkojums
Pamatinformācija
Zīmols
BMW
Modelis
530
Modifikācija
2019 2.0 RWD 135 kW G30 , Iperformance
Nobraukums
47 522
VIN
WBAJA910X0GF99601
Izlaiduma gads
2019
Virsbūves tips
Sedans
Piedziņas veids
RWD
Pārnesumkārba
Automātiskā
Interjers

- Interjers (ādas apdare)
- Interjera krāsa (brūna)
- Sportiska stila sēdekļi
- Karšu kabatas priekšējo sēdekļu aizmugurējā daļā
- Elektriski regulējami sēdekļi (priekšējie)
- Regulējams stūres novietojums
- Multistūre
- Ātrumu pārslēdzēji pie stūres
- Apsildāmi sēdekļi (priekšējie)
- Salona apgaismojums
- Priekšējais elkoņbalsts (ar mantu glabātuvi)

Informācijas sistēmas

- Skārienekrāns
- Bluetooth
- WiFi hotspot
- Digitāls instrumentu panelis
- Audiosistēma (rūpnīcas, MP3, USB, AUX in)
- LCD ekrāns
- Navigācijas sistēma
- Brīvroku sistēma
- Radio

Papildus aprīkojums

- Vieglmetāla diski
- Riepu spiediena kontrole
- Start-stop sistēma
- Āra temperatūras mērītājs
- Sporta pakotne
- Bremžu palīgsistēma braukšanai no kalna
- Garantija
- Servisa grāmatiņa
- Otra atslēga

Drošība

- Stūres pastiprinātājs
- Centrālā atslēga
- Gaisa spilveni
- Elektroniska rokasbremze
- Signalizācija
- Isofix bērnu sēdeklīšu stiprinājumi
- Lietus sensors
- LED lukturi
- Miglas lukturi
- Adaptīvie lukturi
- Automātiskās gaismas

Komforts

- Klimata kontrole
- Elektriski regulējami sānu spoguļi (apsildāmi, nolokāmi, ar atmiņu)
- Elektriski atverami/aizverami stikli
- Kruīza kontrole
- Elektriski atverams bagāžas nodalījuma vāks
- Parkošanās kamera
- Automātiskā parkošanās sistēma
- Parkošanās sensori (priekšējie, aizmugurejie)
- Salona gaisa filtrs

## Priekšlīzinga kalkulators

Par konkrētu līzinga piedāvājumu interesējieties mūsu salonos

## Operatīvais līzings

€ / mēn.

Pirmā iemaksa: EUR

- 10%
- 20%
- 30%
- 40%
- 50%

Atlikusī vērtība

Līzinga periods, gadi

- 3
- 4
- 5

## Finanšu līzings

€ / mēn.

Līzinga periods, gadi

- 3
- 4
- 5

Pirmā iemaksa: EUR

- 10%
- 20%
- 30%
- 40%
- 50%

Inchcape Motors Latvia SIA piedāvā finansējumu sadarbībā ar vadošajām līzinga kompānijām.

Aprēķins veikts, ņemot vērā izvēlēta automobiļa cenu operatīvajā līzingā ar 10% iemaksu uz 60 mēnešiem ar 35% atlikušo vērtību un 100 000 km limitu.

Procentu likme 2.95% + EURIBOR (6 mēn.), administrēšanas maksa 1,5%.Aizņemies atbildīgi, izvērtējot savas iespējas atmaksāt

## Speciālie piedāvājumi

BMW 530 2019 2.0 RWD 135 kW G30 , Iperformance
46 800 €
Izlaiduma gads
2019-07-26
Virsbūves tips
Sedans
Nobraukums
47 522
Piedziņas veids
RWD
Vairāk par auto
Parādīt visu
Visaptveroša automašīnas tehniskā pārbaude
Automašīnu pārbaude atbilstoši Inchcape Certified standartiem.
Visaptverošs pakalpojumu klāsts
Finansēšana, apdrošināšana, testa braucieni, un citi pakalpojumi pieejami uz vietas.
Lietotas automašīnas garantija
6 mēnešu garantija Inchcape Latvija pārstāvētajām markām līdz 10 gadiem / 180 000 km
Jūsu automašīnas atpirkums (Trade-In)
Jūsu automašīna var kalpot kā pirmā iemaksa.
BMW 530 2019 2.0 RWD 135 kW G30 , Iperformance

## Pieprasīt zvanu

Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.

## Paņem mašīnu

Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.

## Apmaiņa

Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.

## Novērtējiet

Automašīnas cenas iepriekšēja novērtēšana
Krāsa
Stūres novietojuma puse
Kreisā Labā
Kā es varu Jums piezvanīt
Jums ērts zvanu laiks
Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.
Pieteikums AutoDNA atskaites saņemšanai
Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.

Pieteikums ir pieņemts, paldies

Pieteikums ir pieņemts, paldies!

Pieteikums ir pieņemts, paldies!

Pieteikums ir pieņemts, paldies!

Pieteikums ir pieņemts, paldies!

Pieteikums ir pieņemts, paldies!

Pieteikums ir pieņemts, paldies

## Pieteikums ONLINE auto apskatei un konsultācijai

Piesakieties automašīnas apskatei un konsultācijai tiešsaistē un gaidiet mūsu pārstāvja zvanu, kura laikā varēsiet vienoties par Jums ērtāko tiešsaistes saziņas kanālu un laiku.

ONLINE saziņas laikā prezentēsim automašīnu, sniegsim ziņas par tās aprīkojumu un tehnisko stāvokli, mūsu pakalpojumiem un finansēšanas iespējām, kā arī atbildes uz visiem Jūsu jautājumiem.

Apliecinu, ka esmu iepazinies un piekrītu Inchcape Motors Latvia Privātuma politikai Piekrītu, ka ar mani sazinās izrādītās intereses ietvaros, izmantojot manis norādīto kontaktinformāciju Piekrītu saņemt informāciju par īpašajiem piedāvājumiem, piemēram, servisa un rezerves daļu akcijām, izpārdošanām un sezonas piedāvājumiem, kā arī aksesuāru, jaunu un mazlietotu automašīnu piedāvājumiem no Inchcape Motors Latvia SIA, kā arī citus piedāvājumus e-pasta, SMS un zvana veidā.

Pieteikums ir pieņemts, paldies

Cienījamie klienti, vēršam Jūsu uzmanību, ka ievērojot valstī noteikto kārtību, sākot ar 15.11.2021. Inchcape Certified autocentri darbosies epidemioloģiski drošā vidē jeb “zaļajā drošības režīmā”.

Mēs turpinām veikt automašīnu tirdzniecību un servisa pakalpojumu sniegšanu, tomēr ceram uz Jūsu saprati, jo autocentra telpās konsultācijas varēsim sniegt tikai klientiem ar sadarbspējīgu vakcinācijas vai pārslimošanas sertifikātu. Klientus, kuriem nav zaļajam drošības režīmam atbilstoša sertifikāta, apkalposim ārpus autocentra - svaigā gaisā.

Uz tikšanos kādā no Inchcape Certified autocentriem!

## Inchcape Certified autocentri turpina darbu, piedāvājot attālinātu auto iegādi

Ievērojot valstī noteiktus ierobežojumus, visi Inchcape Certified autocentri turpina darbību, piedāvājot attālinātu auto iegādi, sākot no 21. oktobra līdz 15. novembrim. Darba laiks darba dienās no 9:00-18:00, bet brīvdienās būs slēgts.

Visas Inchcape Certified automašīnas būs iespējams apskatīt attālināti, kā arī veikt testa braucienu bez tieša kontakta ar uzņēmuma pārstāvi. Visu iegādes procesu būs iespējams veikt pilnībā attālināti caur e-pasta un/vai telefonisku saziņu ar autosalona tirdzniecības konsultantu. Tāpat rasti risinājumi arī attālinātai līzinga noformēšanai.

Pakalpojumu saņemšanas iespējas precizēt, zvanot uz mūsu informatīvajiem tālruņiem, e-pastiem vai nosūtot pieteikumu mājas lapā.

Sazināmies un esam pasargāti!

Cienījamie klienti, ievērojot Valstī noteikto kārtību, sākot ar 21.10.2021 Inchcape Certified tirdzniecības telpas būs slēgtas, tomēr automašīnas būs iespējams apskatīt bez tieša kontakta ar uzņēmuma pārstāvi un iegādāties attālināti.